@@ -1,7 +1,7 @@
 # Author:    Lisandro Dalcin
 # Contact:   dalcinl@gmail.com
 # Copyright: This module has been placed in the public domain.
-# Id:        $Id: mpidistutils.py 106 2007-07-31 18:11:02Z dalcinl $
+# Id:        $Id: mpidistutils.py 165 2008-02-04 21:29:08Z dalcinl $
 
 """
 Support for building mpi4py with distutils.
@@ -37,7 +37,7 @@ def customize_compiler(compiler, environ=None):
     from distutils.sysconfig import get_config_vars
     if environ is None:
         environ = os.environ
-        
+
     if compiler.compiler_type == 'unix':
         (cc, cxx, opt,
          basecflags, cflags, ccshared,
@@ -93,9 +93,19 @@ def customize_mpi_environ(mpicc, mpicxx=None, environ=None):
         if not ldshared:
             environ['LDSHARED'] = mpild
         else:
-            ldshared = ldshared.split(' ', 1)
-            if len(ldshared) == 2:
+            if sys.platform.startswith('aix') \
+                   and 'ld_so_aix' in ldshared:
+                ldshared = ldshared.split(' ', 2)
+            else:
+                ldshared = ldshared.split(' ', 1)
+            if len(ldshared) == 1: # just linker, no flags
+                environ['LDSHARED'] = mpild
+            elif len(ldshared) == 2: # linker and flags
                 environ['LDSHARED'] = mpild + ' ' + ldshared[1]
+            else: # assume using special linker script
+                environ['LDSHARED'] = ldshared[0] + ' '  + \
+                                      mpild       + ' '  + \
+                                      ldshared[2]
     return environ
 
 def _find_mpi_compiler(envvars, executables, path=None):
@@ -114,8 +124,15 @@ def _find_mpi_compiler(envvars, executables, path=None):
         if isinstance(executables, str):
             executables = (executables,)
         for exe in executables:
-            cmd = find_executable(exe, path)
-            if cmd is not None: return cmd
+            try:
+                cmd, args = exe.split(' ', 1)
+            except ValueError:
+                cmd, args = exe, None
+            cmd = find_executable(cmd, path)
+            if cmd is not None:
+                if args is not None:
+                    cmd = cmd + ' ' + args
+                return cmd
     # nothing found
     return None
 
@@ -228,18 +245,23 @@ from distutils.errors import DistutilsOptionError
 
 ConfigTests = [
     # ----------------------------------------------------------------
+
     ('MPI_VERSION',
      'int version; version = MPI_VERSION;'),
     ('MPI_GET_VERSION',
      'MPI_Get_version((int*)0,(int*)0);'),
+
     # ----------------------------------------------------------------
+
     ('MPI_INIT_THREAD',
      "MPI_Init_thread((int*)0,(char***)0,MPI_THREAD_SINGLE,(int*)0);"),
     ('MPI_QUERY_THREAD',
      "MPI_Query_thread((int*)0);"),
     ('MPI_IS_THREAD_MAIN',
      "MPI_Is_thread_main((int*)0);"),
+
     # ----------------------------------------------------------------
+
     ('MPI_WCHAR',
      'MPI_Datatype datatype; datatype = MPI_WCHAR;'),
     ('MPI_SIGNED_CHAR',
@@ -278,53 +300,82 @@ ConfigTests = [
      'MPI_Unpack_external((char*)0,(void*)0,0,(MPI_Aint*)0,(void*)0,0,MPI_DATATYPE_NULL);'),
     ('MPI_PACK_EXTERNAL_SIZE',
      'MPI_Pack_external_size((char*)0,0,MPI_DATATYPE_NULL,(MPI_Aint*)0);'),
+    ('MPI_TYPE_MATCH_SIZE',
+     'MPI_Type_match_size(MPI_TYPECLASS_INTEGER,4,(MPI_Datatype*)0);'),
+
     # ----------------------------------------------------------------
+
     ('MPI_STATUS_IGNORE' ,
      'MPI_Status *status; status = MPI_STATUS_IGNORE;'),
     ('MPI_STATUSES_IGNORE' ,
      'MPI_Status *status; status = MPI_STATUSES_IGNORE;'),
+    ('MPI_STATUS_SET_ELEMENTS' ,
+     'MPI_Status s; MPI_Status_set_elements(&s,MPI_BYTE,0);'),
+    ('MPI_STATUS_SET_CANCELLED' ,
+     'MPI_Status s; MPI_Status_set_cancelled(&s,0);'),
     ('MPI_REQUEST_GET_STATUS' ,
      'MPI_Request_get_status(MPI_REQUEST_NULL,(int*)0,(MPI_Status*)0);'),
+    ('MPI_GREQUEST_START' ,
+     'MPI_Request r; MPI_Grequest_start(0,0,0,0,&r);'),
+    ('MPI_GREQUEST_COMPLETE' ,
+     'MPI_Grequest_complete(MPI_REQUEST_NULL);'),
+
     # ----------------------------------------------------------------
+
     ('MPI_IN_PLACE',
      'MPI_Scan(MPI_IN_PLACE,(void*)0,0,MPI_DATATYPE_NULL,MPI_OP_NULL,MPI_COMM_NULL);'),
     ('MPI_ROOT',
      'MPI_Bcast((void*)0,0,MPI_DATATYPE_NULL,MPI_ROOT,MPI_COMM_NULL);'),
     ('MPI_EXSCAN',
      'MPI_Exscan((void*)0,(void*)0,0,MPI_DATATYPE_NULL,MPI_OP_NULL,MPI_COMM_NULL);'),
+
     # ----------------------------------------------------------------
+
     ('MPI_COMM_GET_ERRHANDLER' ,
      'MPI_Comm_get_errhandler(MPI_COMM_NULL,(MPI_Errhandler*)0);'),
     ('MPI_COMM_SET_ERRHANDLER' ,
      'MPI_Comm_set_errhandler(MPI_COMM_NULL,MPI_ERRHANDLER_NULL);'),
     ('MPI_COMM_CALL_ERRHANDLER',
      'MPI_Comm_call_errhandler(MPI_COMM_NULL,0);'),
+
     # ----------------------------------------------------------------
+
     ('MPI_INFO_NULL',
      'MPI_Info info; info = MPI_INFO_NULL;'),
+
     ('MPI_INFO_CREATE',
      'MPI_Info_create((MPI_Info*)0);'),
     ('MPI_INFO_FREE',
      'MPI_Info_free((MPI_Info*)0);'),
+
     ('MPI_ERR_INFO',       'int ierr; ierr = MPI_ERR_INFO;'),
     ('MPI_ERR_INFO_KEY',   'int ierr; ierr = MPI_ERR_INFO_KEY;'),
     ('MPI_ERR_INFO_VALUE', 'int ierr; ierr = MPI_ERR_INFO_VALUE;'),
     ('MPI_ERR_INFO_NOKEY', 'int ierr; ierr = MPI_ERR_INFO_NOKEY;'),
+
+    ('MPI_MAX_INFO_KEY',   'int imxl; imxl = MPI_MAX_INFO_KEY;'),
+    ('MPI_MAX_INFO_VAL',   'int imxl; imxl = MPI_MAX_INFO_KEY;'),
+
     # ----------------------------------------------------------------
+
     ('MPI_WIN_NULL',
      'MPI_Win win; win = MPI_WIN_NULL;'),
+
     ('MPI_WIN_CREATE',
      'MPI_Win_create((void*)0,(MPI_Aint)0,0,MPI_INFO_NULL,MPI_COMM_NULL,(MPI_Win*)0);'),
     ('MPI_WIN_FREE',
      'MPI_Win_free((MPI_Win*)0);'),
+
     ('MPI_WIN_TEST',
      'MPI_Win_test(MPI_WIN_NULL,(int*)0);'),
     ('MPI_WIN_LOCK',
      'MPI_Win_lock(0,0,0,MPI_WIN_NULL);'),
     ('MPI_WIN_UNLOCK',
      'MPI_Win_unlock(0,MPI_WIN_NULL);'),
-    ('MPI_LOCK_EXCLUSIVE', 'int lock; lock = MPI_LOCK_EXCLUSIVE;'  ),
-    ('MPI_LOCK_SHARED'   , 'int lock; lock = MPI_LOCK_SHARED;'     ),
+
+    ('MPI_LOCK_EXCLUSIVE'  , 'int lock; lock = MPI_LOCK_EXCLUSIVE;'  ),
+    ('MPI_LOCK_SHARED'     , 'int lock; lock = MPI_LOCK_SHARED;'     ),
+
     ('MPI_ERR_WIN'         , 'int ierr; ierr = MPI_ERR_WIN;'         ),
     ('MPI_ERR_BASE'        , 'int ierr; ierr = MPI_ERR_BASE;'        ),
     ('MPI_ERR_SIZE'        , 'int ierr; ierr = MPI_ERR_SIZE;'        ),
@@ -333,25 +384,64 @@ ConfigTests = [
     ('MPI_ERR_ASSERT'      , 'int ierr; ierr = MPI_ERR_ASSERT;'      ),
     ('MPI_ERR_RMA_CONFLICT', 'int ierr; ierr = MPI_ERR_RMA_CONFLICT;'),
     ('MPI_ERR_RMA_SYNC'    , 'int ierr; ierr = MPI_ERR_RMA_SYNC;'    ),
-    ('MPI_REPLACE',
-     'MPI_Op op; op = MPI_REPLACE;'),
+
+    ('MPI_REPLACE', 'MPI_Op op; op = MPI_REPLACE;'),
+
     # ----------------------------------------------------------------
+
     ('MPI_FILE_NULL',
      'MPI_File file; file = MPI_FILE_NULL;'),
+
     ('MPI_FILE_OPEN',
      'MPI_File_open(MPI_COMM_NULL,(char*)0,0,MPI_INFO_NULL,(MPI_File*)0);'),
     ('MPI_FILE_CLOSE',
      'MPI_File_close((MPI_File*)0);'),
-    ('MPI_DISPLACEMENT_CURRENT',
-     'MPI_Offset disp; disp = MPI_DISPLACEMENT_CURRENT;'),
-    ('MPI_MAX_DATAREP_STRING', 'int len; len = MPI_MAX_DATAREP_STRING;'),
+
+    ('MPI_MODE_RDONLY',               'int mode; mode = MPI_MODE_RDONLY;'),
+    ('MPI_MODE_RDWR',                 'int mode; mode = MPI_MODE_RDWR;'),
+    ('MPI_MODE_WRONLY',               'int mode; mode = MPI_MODE_WRONLY;'),
+    ('MPI_MODE_CREATE',               'int mode; mode = MPI_MODE_CREATE;'),
+    ('MPI_MODE_EXCL',                 'int mode; mode = MPI_MODE_EXCL;'),
+    ('MPI_MODE_DELETE_ON_CLOSE',      'int mode; mode = MPI_MODE_DELETE_ON_CLOSE;'),
+    ('MPI_MODE_UNIQUE_OPEN',          'int mode; mode = MPI_MODE_UNIQUE_OPEN;'),
+    ('MPI_MODE_SEQUENTIAL',           'int mode; mode = MPI_MODE_SEQUENTIAL;'),
+    ('MPI_MODE_APPEND',               'int mode; mode = MPI_MODE_APPEND;'),
+
+    ('MPI_SEEK_SET',                  'int seek; seek = MPI_SEEK_SET;'),
+    ('MPI_SEEK_CUR',                  'int seek; seek = MPI_SEEK_CUR;'),
+    ('MPI_SEEK_END',                  'int seek; seek = MPI_SEEK_END;'),
+
+    ('MPI_ERR_FILE',                  'int ierr; ierr = MPI_ERR_FILE;'),
+    ('MPI_ERR_NOT_SAME',              'int ierr; ierr = MPI_ERR_NOT_SAME;'),
+    ('MPI_ERR_AMODE',                 'int ierr; ierr = MPI_ERR_AMODE;'),
+    ('MPI_ERR_UNSUPPORTED_DATAREP',   'int ierr; ierr = MPI_ERR_UNSUPPORTED_DATAREP;'),
+    ('MPI_ERR_UNSUPPORTED_OPERATION', 'int ierr; ierr = MPI_ERR_UNSUPPORTED_OPERATION;'),
+    ('MPI_ERR_NO_SUCH_FILE',          'int ierr; ierr = MPI_ERR_NO_SUCH_FILE;'),
+    ('MPI_ERR_FILE_EXISTS',           'int ierr; ierr = MPI_ERR_FILE_EXISTS;'),
+    ('MPI_ERR_BAD_FILE',              'int ierr; ierr = MPI_ERR_BAD_FILE;'),
+    ('MPI_ERR_ACCESS',                'int ierr; ierr = MPI_ERR_ACCESS;'),
+    ('MPI_ERR_NO_SPACE',              'int ierr; ierr = MPI_ERR_NO_SPACE;'),
+    ('MPI_ERR_QUOTA',                 'int ierr; ierr = MPI_ERR_QUOTA;'),
+    ('MPI_ERR_READ_ONLY',             'int ierr; ierr = MPI_ERR_READ_ONLY;'),
+    ('MPI_ERR_FILE_IN_USE',           'int ierr; ierr = MPI_ERR_FILE_IN_USE;'),
+    ('MPI_ERR_DUP_DATAREP',           'int ierr; ierr = MPI_ERR_DUP_DATAREP;'),
+    ('MPI_ERR_CONVERSION',            'int ierr; ierr = MPI_ERR_CONVERSION;'),
+    ('MPI_ERR_IO',                    'int ierr; ierr = MPI_ERR_IO;'),
+
+    ('MPI_DISPLACEMENT_CURRENT', 'MPI_Offset val; val = MPI_DISPLACEMENT_CURRENT;'),
+    ('MPI_MAX_DATAREP_STRING',   'int val;        val = MPI_MAX_DATAREP_STRING;'),
+
     # ----------------------------------------------------------------
+
     ('MPI_ALLOC_MEM',
-     'MPI_Alloc_mem((MPI_Aint)0,MPI_INFO_NULL,(void*)0);'             ),
+     'MPI_Alloc_mem((MPI_Aint)0,MPI_INFO_NULL,(void*)0);'),
     ('MPI_FREE_MEM',
-     'MPI_Free_mem((void*)0);'                                       ),
-    ('MPI_ERR_NO_MEM', 'int ierr; ierr = MPI_ERR_NO_MEM;'            ),
+     'MPI_Free_mem((void*)0);'),
+
+    ('MPI_ERR_NO_MEM', 'int ierr; ierr = MPI_ERR_NO_MEM;'),
+
     # ----------------------------------------------------------------
+
     ('MPI_OPEN_PORT',
      'MPI_Open_port(MPI_INFO_NULL,(char*)0);'),
     ('MPI_CLOSE_PORT',
@@ -362,18 +452,13 @@ ConfigTests = [
      'MPI_Unpublish_name((char*)0, MPI_INFO_NULL,(char*)0);'),
     ('MPI_LOOKUP_NAME',
      'MPI_Lookup_name((char*)0, MPI_INFO_NULL,(char*)0);'),
+
     ('MPI_COMM_ACCEPT',
      'MPI_Comm_accept((char*)0,MPI_INFO_NULL,0,MPI_COMM_NULL,(MPI_Comm*)0);'),
     ('MPI_COMM_CONNECT',
      'MPI_Comm_connect((char*)0,MPI_INFO_NULL,0,MPI_COMM_NULL,(MPI_Comm*)0);'),
     ('MPI_COMM_DISCONNECT',
      'MPI_Comm comm = MPI_COMM_NULL; MPI_Comm_disconnect(&comm);'),
-    ('MPI_APPNUM',
-     'int keyval = MPI_KEYVAL_INVALID; keyval = MPI_APPNUM;'),
-    ('MPI_UNIVERSE_SIZE',
-     'int keyval = MPI_KEYVAL_INVALID; keyval = MPI_UNIVERSE_SIZE;'),
-    ('MPI_ERRCODES_IGNORE',
-     'int* ec; ec = MPI_ERRCODES_IGNORE;'),
     ('MPI_COMM_SPAWN',
      'MPI_Comm_spawn((char*)0,(char**)0,0,' \
      'MPI_INFO_NULL,0,MPI_COMM_NULL,(MPI_Comm*)0,(int*)0);'),
@@ -381,11 +466,18 @@ ConfigTests = [
      'MPI_Comm_get_parent((MPI_Comm*)0);'),
     ('MPI_COMM_JOIN',
      'MPI_Comm_join(0,(MPI_Comm*)0);'),
+
+    ('MPI_ERRCODES_IGNORE', 'int *eci; eci  = MPI_ERRCODES_IGNORE;'),
+    ('MPI_APPNUM',          'int kval; kval = MPI_APPNUM;'),
+    ('MPI_UNIVERSE_SIZE',   'int kval; kval = MPI_UNIVERSE_SIZE;'),
+
     ('MPI_ERR_NAME',    'int ierr; ierr = MPI_ERR_NAME;'),
     ('MPI_ERR_PORT',    'int ierr; ierr = MPI_ERR_PORT;'),
     ('MPI_ERR_SERVICE', 'int ierr; ierr = MPI_ERR_SERVICE;'),
     ('MPI_ERR_SPAWN',   'int ierr; ierr = MPI_ERR_SPAWN;'),
+
     # ----------------------------------------------------------------
+
     ('MPI_TYPE_GET_NAME',
      'MPI_Type_get_name(MPI_DATATYPE_NULL,(char*)0,(int*)0);'),
     ('MPI_TYPE_SET_NAME',
@@ -398,9 +490,12 @@ ConfigTests = [
      'MPI_Win_get_name(MPI_WIN_NULL,(char*)0,(int*)0);'),
     ('MPI_WIN_SET_NAME',
      'MPI_Win_set_name(MPI_WIN_NULL,(char*)0);'),
-    ('MPI_MAX_OBJECT_NAME', 'int len; len = MPI_MAX_OBJECT_NAME;'),
+    ('MPI_MAX_OBJECT_NAME', 'int val; val = MPI_MAX_OBJECT_NAME;'),
+
     # ----------------------------------------------------------------
+
     ('MPI_ERR_KEYVAL', 'int ierr; ierr = MPI_ERR_KEYVAL;'),
+
     # ----------------------------------------------------------------
     ]
 
@@ -436,7 +531,7 @@ cmd_mpi_opts = [
      "to look for MPI includes/libraries, "
      "overrides environmental variables 'MPICFG' "
      "(defaults to section 'mpi' in configuration file 'mpi.cfg')"),
-    
+
     ('try-mpi-2', None,
      "test for availability of MPI 2 features"),
 
@@ -448,7 +543,7 @@ cmd_mpi_opts = [
 
     ('enable-leak-warning', None,
      "isuue a warning if any MPI handle is (possibly) leaked"),
-    
+
     ]
 
 def _cmd_opts_names(cmd_opts):
@@ -459,7 +554,7 @@ def _cmd_opts_names(cmd_opts):
         option = option.replace('-','_')
         optlist.append(option)
     return optlist
-        
+
 def _thread_level(thread_level):
     if not thread_level:
         return None
@@ -468,8 +563,9 @@ def _thread_level(thread_level):
         return None
     valid_levels = ['single', 'funneled', 'serialized', 'multiple']
     if thread_level not in valid_levels:
-        raise DistutilsOptionError, \
-              ("thread-level must be one of " + ','.join(valid_levels))
+        raise DistutilsOptionError(
+            ("thread-level must be one of " + ','.join(valid_levels))
+            )
     return thread_level
 
 def _enable_fast_errcheck(flag):
@@ -489,13 +585,13 @@ class config(cmd_config.config):
         mpiopts = _cmd_opts_names(cmd_mpi_opts)
         for op in mpiopts:
             setattr(self, op, None)
-        
+
     def finalize_options(self):
         cmd_config.config.finalize_options(self)
         if not self.noisy:
             self.dump_source = 0
         self.thread_level = _thread_level(self.thread_level)
-        
+
     def find_mpi_compiler(self, envvars, executables, path=None):
         return _find_mpi_compiler(envvars, executables, path)
 
@@ -545,7 +641,7 @@ class config(cmd_config.config):
             result = self.try_config_test(code)
             macros.append(('HAVE_%s' % name, int(result)))
         return macros
-        
+
     def try_config_test(self, lines):
         if type(lines) is not str:
             lines = '\n  '.join(lines)
@@ -554,18 +650,18 @@ class config(cmd_config.config):
                              include_dirs=self.include_dirs,
                              libraries=self.libraries,
                              library_dirs=self.library_dirs)
-        
+
 
 class build(cmd_build.build):
 
     user_options = cmd_build.build.user_options + cmd_mpi_opts
-    
+
     def initialize_options(self):
         cmd_build.build.initialize_options(self)
         mpiopts = _cmd_opts_names(cmd_mpi_opts)
         for op in mpiopts:
             setattr(self, op, None)
-        
+
     def finalize_options(self):
         cmd_build.build.finalize_options(self)
         config_cmd = self.get_finalized_command('config')
@@ -588,10 +684,10 @@ class build_ext(cmd_build_ext.build_ext):
 
     def finalize_options(self):
         cmd_build_ext.build_ext.finalize_options(self)
-        # XXX I have to figure out why this is needed
         import sys, os
-        if (sys.platform.startswith('linux') and
-            sysconfig.get_config_var('Py_ENABLE_SHARED')):
+        if (sys.platform.startswith('linux') or \
+            sys.platform.startswith('gnu')) and \
+            sysconfig.get_config_var('Py_ENABLE_SHARED'):
             try:
                 py_version = sysconfig.get_python_version()
                 bad_pylib_dir = os.path.join(sys.prefix, "lib",
@@ -600,8 +696,9 @@ class build_ext(cmd_build_ext.build_ext):
                 self.library_dirs.remove(bad_pylib_dir)
             except ValueError:
                 pass
-            pylib_dir = os.path.join(sys.prefix, "lib")
-            self.library_dirs.append(pylib_dir)
+            pylib_dir = sysconfig.get_config_var("LIBDIR")
+            if pylib_dir not in self.library_dirs:
+                self.library_dirs.append(pylib_dir)
         build_cmd = self.get_finalized_command('build')
         if isinstance(build_cmd,  build):
             mpiopts = _cmd_opts_names(cmd_mpi_opts)
@@ -616,8 +713,8 @@ class build_ext(cmd_build_ext.build_ext):
         config_info = self.configure_extensions()
         mpicc = mpicxx = None
         if config_info:
-            mpicc = config_info.get('mpicc',[None])[0]
-            mpicxx = config_info.get('mpicxx',[None])[0]
+            mpicc = config_info.get('mpicc')
+            mpicxx = config_info.get('mpicxx')
         compiler = self.configure_compiler(mpicc=mpicc, mpicxx=mpicxx)
         # extra configuration, MPI 2 features
         if self.try_mpi_2:
@@ -684,7 +781,7 @@ class build_ext(cmd_build_ext.build_ext):
             log.info("MPI configuration: "
                      "from section '%s' in file/s '%s'", sect, fnames)
         return cfg_info
-        
+
     def configure_extension(self, extension, config_info):
         _configure(extension, config_info)
 
@@ -702,6 +799,11 @@ from distutils.command import install_lib as cmd_install_lib
 class Distribution(cls_Distribution):
 
     def __init__ (self, attrs=None):
+        # PEP 314
+        self.provides = None
+        self.requires = None
+        self.obsoletes = None
+        # supports 'executables' keyword
         self.executables = None
         cls_Distribution.__init__(self, attrs)
 
@@ -712,7 +814,7 @@ class Distribution(cls_Distribution):
 # Executable class
 
 class Executable(Extension):
-    
+
     pass
 
 
@@ -721,14 +823,14 @@ class Executable(Extension):
 _build_ext = build_ext
 
 class build_exe(_build_ext):
-    
+
     description = "build binary executable components"
 
     user_options = [
         ('build-exe=', None,
          "build directory for executable components"),
         ] + _build_ext.user_options
-    
+
 
     def initialize_options (self):
         _build_ext.initialize_options(self)
@@ -766,10 +868,11 @@ class build_exe(_build_ext):
         from distutils.dep_util import newer_group
         sources = ext.sources
         if sources is None or type(sources) not in (ListType, TupleType):
-            raise DistutilsSetupError, \
-                  ("in 'executable' option (extension '%s'), " +
-                   "'sources' must be present and must be " +
-                   "a list of source filenames") % ext.name
+            raise DistutilsSetupError(
+                ("in 'executable' option (extension '%s'), " +
+                 "'sources' must be present and must be " +
+                 "a list of source filenames") % ext.name
+                )
         sources = list(sources)
         fullname = self.get_ext_fullname(ext.name)
         ext_filename = os.path.join(self.build_exe,
@@ -796,6 +899,7 @@ class build_exe(_build_ext):
         # any sensible compiler will give precedence to later
         # command line args.  Hence we combine them in order:
         extra_args = ext.extra_compile_args or []
+        extra_args = extra_args[:]
 
         macros = ext.define_macros[:]
         for undef in ext.undef_macros:
@@ -826,11 +930,16 @@ class build_exe(_build_ext):
         if ext.extra_objects:
             objects.extend(ext.extra_objects)
         extra_args = ext.extra_link_args or []
-        # Just in (default) case libpythonX.X.a is a static library
-        ldshflag = sysconfig.get_config_var('LINKFORSHARED')
-        if ldshflag is not None:
-            extra_args.extend(ldshflag.split())
-
+        extra_args = extra_args[:]
+        # Get special linker flags for building a executable with
+        # bundled Python library, also fix location of needed
+        # python.exp file on AIX
+        ldshflag = sysconfig.get_config_var('LINKFORSHARED') or ''
+        if sys.platform.startswith('aix'):
+            python_lib = sysconfig.get_python_lib(standard_lib=1)
+            python_exp = os.path.join(python_lib, 'config', 'python.exp')
+            ldshflag = ldshflag.replace('Modules/python.exp', python_exp)
+        extra_args.extend(ldshflag.split())
         # Detect target language, if not provided
         language = ext.language or self.compiler.detect_language(sources)
         self.compiler.link_executable(
@@ -850,7 +959,7 @@ class build_exe(_build_ext):
 class install_exe(cmd_install_lib.install_lib):
 
     description = "install binary executable components"
-    
+
     def finalize_options (self):
         self.set_undefined_options('install',
                                    ('force', 'force'),
@@ -902,12 +1011,12 @@ class clean_exe(Command):
         ]
 
     boolean_options = ['all']
-    
+
     def initialize_options(self):
         self.build_base = None
         self.build_exe  = None
         self.all        = None
-        
+
     def finalize_options(self):
         self.set_undefined_options('build',
                                    ('build_base', 'build_base'))
