@@ -75,12 +75,12 @@ def maxvalue(a):
 
 
 class TestCollBufBase(object):
-    
+
     COMM = MPI.COMM_NULL
 
     def testBarrier(self):
         self.COMM.Barrier()
-    
+
     def testBcast(self):
         size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
@@ -160,13 +160,13 @@ class TestCollBufBase(object):
                                            mkbuf(rbuf, datatype, size))
                         for value in rbuf:
                             self.assertEqual(value, root)
-        
+
     def assertAlmostEqual(self, first, second):
         num = float(float(second-first))
         den = float(second+first)/2 or 1.0
         if (abs(num/den) > 1e-2):
-            raise self.failureException, '%r != %r' % (first, second)
-    
+            raise self.failureException('%r != %r' % (first, second))
+
     def testReduce(self):
         size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
@@ -220,7 +220,7 @@ class TestCollBufBase(object):
                                 self.assertEqual(value, i)
                             elif op == MPI.MIN:
                                 self.assertEqual(value, i)
-        
+
 
     def testScan(self):
         size = self.COMM.Get_size()
@@ -304,7 +304,7 @@ class TestCollBufBase(object):
                                     self.assertEqual(value, -1)
                                 else:
                                     self.assertEqual(value, i)
-                    
+
                         #
                         if rank == root:
                             buf = array(typecode, range(10))
@@ -321,12 +321,11 @@ class TestCollBufBase(object):
                                     self.assertEqual(value, -1)
                                 else:
                                     self.assertEqual(value, i)
-        
+
 
 class TestCollBufInplaceBase(object):
 
     def testGather(self):
-        if MPI.IN_PLACE == 0: return
         size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
         for mkbufs, array, equal in arrayimpl:
@@ -351,7 +350,6 @@ class TestCollBufInplaceBase(object):
                             self.assertEqual(value, root)
 
     def testScatter(self):
-        if MPI.IN_PLACE == 0: return
         size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
         for mkbufs, array, equal in arrayimpl:
@@ -375,7 +373,6 @@ class TestCollBufInplaceBase(object):
                                 self.assertEqual(value, root)
 
     def testAllgather(self):
-        if MPI.IN_PLACE == 0: return
         size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
         for mkbufs, array, equal in arrayimpl:
@@ -390,7 +387,7 @@ class TestCollBufInplaceBase(object):
                             return
                         for value in buf:
                             self.assertEqual(value, count)
-    
+
     def testReduce(self):
         size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
@@ -454,7 +451,7 @@ class TestCollBufInplaceBase(object):
                             elif op == MPI.MIN:
                                 self.assertEqual(value, i)
 
-    
+
 class TestCollBufSelf(TestCollBufBase, unittest.TestCase):
     COMM = MPI.COMM_SELF
 
@@ -467,10 +464,13 @@ class TestCollBufInplaceSelf(TestCollBufInplaceBase, unittest.TestCase):
 class TestCollBufInplaceWorld(TestCollBufInplaceBase, unittest.TestCase):
     COMM = MPI.COMM_WORLD
 
+if MPI.IN_PLACE is None:
+    del TestCollBufInplaceBase
+    del TestCollBufInplaceSelf
+    del TestCollBufInplaceWorld
 
 if __name__ == '__main__':
     try:
         unittest.main()
     except SystemExit:
         pass
-    
