@@ -24,7 +24,7 @@ messages += [ list(_basic),
               dict([('k%d' % key, val)
                     for key, val in enumerate(_basic)])
               ]
-           
+
 
 
 [None, True, False, 7, 3.14, 1+2j, 'mpi4py',
@@ -35,7 +35,7 @@ messages += [ list(_basic),
 #messages = [messages*1000, messages*1000]
 
 class TestCollObjBase(object):
-    
+
     COMM = MPI.COMM_NULL
 
     def testBarrier(self):
@@ -68,7 +68,7 @@ class TestCollObjBase(object):
                 else:
                     rmess = self.COMM.Scatter(None, root=root)
                 self.assertEqual(rmess, smess)
-        
+
     def testAllgather(self):
         size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
@@ -82,7 +82,7 @@ class TestCollObjBase(object):
         for smess in messages + [messages]:
             rmess = self.COMM.Alltoall([smess] * size, None)
             self.assertEqual(rmess, [smess] * size)
-    
+
     def testReduce(self):
         size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
@@ -195,7 +195,7 @@ class TestInterCollObjBase(object):
         self.INTERCOMM = self.INTRACOMM.Create_intercomm(self.LOCAL_LEADER,
                                                          self.BASECOMM,
                                                          self.REMOTE_LEADER)
-        
+
     def tearDown(self):
         if self.INTRACOMM != MPI.COMM_NULL:
             self.INTRACOMM.Free()
@@ -209,7 +209,7 @@ class TestInterCollObjBase(object):
             self.INTERCOMM.Barrier()
         except NotImplementedError:
             return
-        
+
     def testBcast(self):
         if self.INTRACOMM == MPI.COMM_NULL: return
         if self.INTERCOMM == MPI.COMM_NULL: return
@@ -232,7 +232,7 @@ class TestInterCollObjBase(object):
                             self.assertEqual(rmess, smess)
                 except NotImplementedError:
                     return
-        
+
     def testGather(self):
         if self.INTRACOMM == MPI.COMM_NULL: return
         if self.INTERCOMM == MPI.COMM_NULL: return
@@ -357,7 +357,7 @@ class TestInterCollObjBase(object):
                 self.assertEqual(value, rsize-1)
             elif op == MPI.MIN:
                 self.assertEqual(value, 0)
-        
+
 
 class TestCollObjSelf(TestCollObjBase, unittest.TestCase):
     COMM = MPI.COMM_SELF
@@ -394,10 +394,14 @@ if _name == 'OpenMPI':
     if _version < (1, 2, 4):
         del TestInterCollObjWorld
         del TestInterCollObjWorldDup
-    
+
+if MPI.ROOT is None:
+    del TestInterCollObjBase
+    del TestInterCollObjWorld
+    del TestInterCollObjWorldDup
+
 if __name__ == '__main__':
     try:
         unittest.main()
     except SystemExit:
         pass
-    
