@@ -12,7 +12,7 @@ class TestEnviron(unittest.TestCase):
         self.assertEqual(len(version), 2)
         self.assertTrue(type(version[0]) is int)
         self.assertTrue(type(version[1]) is int)
-        
+
     def testTime(self):
         tick = MPI.Wtick()
         self.assertTrue(tick > 0.0)
@@ -22,7 +22,7 @@ class TestEnviron(unittest.TestCase):
 
     def testProcessorName(self):
         procname = MPI.Get_processor_name()
-        self.assertTrue(isinstance(procname, basestring))
+        self.assertTrue(isinstance(procname, type('')))
 
     def testHostPorcessor(self):
         size = MPI.COMM_WORLD.Get_size()
@@ -39,14 +39,14 @@ class TestEnviron(unittest.TestCase):
     def testAppNum(self):
         appnum = MPI.APPNUM
         self.assertTrue(appnum == MPI.UNDEFINED or appnum >= 0)
-        
+
     def testUniverseSize(self):
         univsz = MPI.UNIVERSE_SIZE
         self.assertTrue(univsz == MPI.UNDEFINED or univsz >= 0)
-        
 
 
-       
+
+
 if __name__ == '__main__':
     try:
         unittest.main()
