@@ -6,7 +6,7 @@ class TestFileBase(object):
     COMM = MPI.COMM_NULL
 
     prefix = 'mpi4py'
-    
+
     def setUp(self):
         self.FILE = MPI.FILE_NULL
         self.fd, self.fname = tempfile.mkstemp(prefix=self.prefix)
@@ -19,15 +19,14 @@ class TestFileBase(object):
         except NotImplementedError:
             os.close(self.fd)
             return
-        
+
     def tearDown(self):
         if self.FILE == MPI.FILE_NULL: return
         amode = self.FILE.amode
+        os.close(self.fd)
         self.FILE.Close()
         if not (amode & MPI.MODE_DELETE_ON_CLOSE):
             MPI.File.Delete(self.fname, MPI.INFO_NULL)
-        os.close(self.fd)
-        
 
     def testPreallocate(self):
         self.FILE.Preallocate(0)
@@ -112,7 +111,7 @@ class TestFileBase(object):
         self.FILE.Seek(offset, MPI.SEEK_SET)
         pos = self.FILE.Get_position()
         self.assertEqual(pos, offset)
-        
+
     def testSeekGetPositionShared(self):
         offset = 0
         self.FILE.Seek_shared(offset, MPI.SEEK_END)
@@ -139,7 +138,7 @@ class TestFileNull(unittest.TestCase):
 
     def tearDown(self):
         MPI.FILE_NULL.Set_errhandler(MPI.ERRORS_RETURN)
-    
+
     def testGetSetErrhandler(self):
         eh = MPI.FILE_NULL.Get_errhandler()
         self.assertEqual(eh, MPI.ERRORS_RETURN)
@@ -152,7 +151,7 @@ class TestFileNull(unittest.TestCase):
         eh = MPI.FILE_NULL.Get_errhandler()
         self.assertEqual(eh, MPI.ERRORS_RETURN)
         eh.Free()
-        
+
 
 class TestFileSelf(TestFileBase, unittest.TestCase):
     COMM = MPI.COMM_SELF
@@ -172,16 +171,15 @@ if _name == 'OpenMPI':
         del TestFileBase.testGetTypeExtent
         del TestFileBase.testSeekGetPosition
         del TestFileBase.testSeekGetPositionShared
-if _name == 'LAM/MPI':
-    del TestFileNull
-    del TestFileSelf
-if _name == 'MPICH':
-    del TestFileNull
-    del TestFileSelf
+else:
+    try:
+        MPI.FILE_NULL.Get_errhandler().Free()
+    except NotImplementedError:
+        del TestFileNull
+        del TestFileSelf
 
 if __name__ == '__main__':
     try:
         unittest.main()
     except SystemExit:
         pass
-    
