@@ -45,7 +45,7 @@ class TestGroupBase(object):
         group = MPI.Group.Difference(self.GROUP, self.GROUP)
         self.assertEqual(MPI.Group.Compare(group, MPI.GROUP_EMPTY), MPI.IDENT)
         group.Free()
-        
+
     def testIntersect(self):
         group = MPI.Group.Intersect(MPI.GROUP_EMPTY, self.GROUP)
         self.assertEqual(MPI.Group.Compare(group, MPI.GROUP_EMPTY), MPI.IDENT)
@@ -76,7 +76,7 @@ class TestGroupBase(object):
         group = self.GROUP.Range_incl(ranges)
         self.assertEqual(MPI.Group.Compare(group, self.GROUP), MPI.IDENT)
         group.Free()
-        
+
     def testRangeExcl(self):
         if self.GROUP == MPI.GROUP_EMPTY: return
         group = self.GROUP.Range_excl([])
@@ -86,7 +86,7 @@ class TestGroupBase(object):
         group = self.GROUP.Range_excl(ranges)
         self.assertEqual(MPI.Group.Compare(group, MPI.GROUP_EMPTY), MPI.IDENT)
         group.Free()
-        
+
     def testTranslRanks(self):
         group1 = self.GROUP
         group2 = self.GROUP
@@ -98,7 +98,7 @@ class TestGroupBase(object):
         if self.GROUP == MPI.GROUP_EMPTY: return
         group1 = self.GROUP
         group2 = self.GROUP
-        ranks1 = [MPI.PROC_NULL] * 10
+        ranks1 = getattr(self, 'PROC_NULL', [MPI.PROC_NULL] * 10)
         ranks2 = MPI.Group.Translate_ranks(group1, ranks1, group2)
         self.assertEqual(ranks1, ranks2)
 
@@ -111,7 +111,7 @@ class TestGroupBase(object):
         for rank in ranks2:
             self.assertEqual(rank, MPI.UNDEFINED)
 
-        
+
 class TestGroupNull(unittest.TestCase):
 
     def testNull(self):
@@ -153,7 +153,7 @@ class TestGroupSelf(TestGroupBase, unittest.TestCase):
     def testRank(self):
         rank = self.GROUP.Get_rank()
         self.assertEqual(rank, 0)
-    
+
 class TestGroupWorld(TestGroupBase, unittest.TestCase):
     def setUp(self):
         self.GROUP = MPI.COMM_WORLD.Get_group()
@@ -166,7 +166,11 @@ class TestGroupWorld(TestGroupBase, unittest.TestCase):
         size = self.GROUP.Get_size()
         rank = self.GROUP.Get_rank()
         self.assertTrue(rank >= 0 and rank < size)
-    
+
+_name, _version = MPI._mpi_info()
+if _name == 'MPICH':
+    TestGroupBase.PROC_NULL = MPI.PROC_NULL
+
 
 if __name__ == '__main__':
     try:
